/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef SOLVENTEXCLUDEDSURFACE_H
#define SOLVENTEXCLUDEDSURFACE_H

#include <U2Algorithm/MolecularSurface.h>

namespace U2
{

class Surface;

class SolventExcludedSurface : public MolecularSurface
{
public:
    SolventExcludedSurface();
    virtual void calculate(const QList<SharedAtom>& atoms, int& progress);
    virtual qint64 estimateMemoryUsage(int numberOfAtoms);
};

class SolventExcludedSurfaceFactory : public MolecularSurfaceFactory
{
public:
    virtual MolecularSurface *createInstance()const;
    bool hasConstraints(const BioStruct3D& biostruc) const;
};

} // namespace

#endif // SOLVENTEXCLUDEDSURFACE_H
